@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -59,7 +59,7 @@ tp_dealloc (disk_disk_o *self)
 static PyObject *
 tp_getter_size (disk_disk_o *self)
 {
-  return PyLong_FromUnsignedLongLong (self->obj->get_size ());
+  return mobius::py::pylong_from_std_uint64_t (self->obj->get_size ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -77,7 +77,7 @@ tp_getter_sector_size (disk_disk_o *self)
 static PyObject *
 tp_getter_name (disk_disk_o *self)
 {
-  return PyString_from_std_string (self->obj->get_name ());
+  return PyString2_from_std_string (self->obj->get_name ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -86,7 +86,7 @@ tp_getter_name (disk_disk_o *self)
 static PyObject *
 tp_getter_type (disk_disk_o *self)
 {
-  return PyString_from_std_string (self->obj->get_type ());
+  return PyString2_from_std_string (self->obj->get_type ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -127,7 +127,18 @@ static PyGetSetDef tp_getset[] =
 static PyObject *
 tp_f_is_available (disk_disk_o *self, PyObject *)
 {
-  return PyBool_FromLong (self->obj->is_available ());
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pybool_from_bool (self->obj->is_available ());
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -136,7 +147,18 @@ tp_f_is_available (disk_disk_o *self, PyObject *)
 static PyObject *
 tp_f_new_reader (disk_disk_o *self, PyObject *)
 {
-  return PyMobius_IO_Reader_from_cpp (self->obj->new_reader ());
+  PyObject *ret = nullptr;
+
+  try
+    {
+     ret = PyMobius_IO_Reader_from_cpp (self->obj->new_reader ());
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -145,10 +167,21 @@ tp_f_new_reader (disk_disk_o *self, PyObject *)
 static PyObject *
 tp_f_scan (disk_disk_o *self, PyObject *)
 {
-  self->obj->scan ();
+  PyObject *ret = nullptr;
 
-  Py_INCREF (Py_None);
-  return Py_None;
+  try
+    {
+      self->obj->scan ();
+
+      Py_INCREF (Py_None);
+      ret = Py_None;
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -157,7 +190,18 @@ tp_f_scan (disk_disk_o *self, PyObject *)
 static PyObject *
 tp_f_get_metadata (disk_disk_o *self, PyObject *)
 {
-  return PyList_FromMetadata (self->obj->get_metadata ());
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = PyList_FromMetadata (self->obj->get_metadata ());
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
